@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # This file is a part of Pluggable Output Processor
@@ -50,7 +49,6 @@ def pos_to_offset(line, requested_pos):
         escape sequences.
 
         TODO Consider other than color ESC sequences
-        TODO Unit tests for this crap!
     '''
     assert(isinstance(line, str) and isinstance(requested_pos, int) and requested_pos < len(line))
     inside_esc_seq = False
